@@ -4,7 +4,7 @@ from unittest import TestCase
 
 from .continuous import ContinuousTimeRange
 from .timerange import TimeRange
-from .daterange import date_range
+from .date_range import daterange
 from .month import CalendarMonth
 
 date = (2021, 5, 20)
@@ -105,7 +105,7 @@ class TimeRangeInitializationTest(unittest.TestCase):
 
     def test_initialization_with_start_and_end_as_dates(self):
         string = "TimeRange(start=datetime.datetime(2021, 5, 20, 0, 0), end=datetime.datetime(2021, 5, 21, 23, 59, 59, 999999))"
-        self.assertEqual(str(date_range(start=datetime(2021, 5, 20), end=datetime(2021, 5, 21))), string)
+        self.assertEqual(str(daterange(start=datetime(2021, 5, 20), end=datetime(2021, 5, 21))), string)
 
     def test_initialization_with_start_and_duration(self):
         t = TimeRange(start=start, duration=timedelta(hours=8))
@@ -115,7 +115,7 @@ class TimeRangeInitializationTest(unittest.TestCase):
 
     def test_initialization_with_start_and_duration_from_dates(self):
         string = "TimeRange(start=datetime.datetime(2021, 5, 20, 0, 0), end=datetime.datetime(2021, 5, 21, 23, 59, 59, 999999))"
-        self.assertEqual(str(date_range(start=datetime(2021, 5, 20), days=1)), string)
+        self.assertEqual(str(daterange(start=datetime(2021, 5, 20), days=1)), string)
 
 
     def test_start_end_integrity(self):
